@@ -1,5 +1,5 @@
 import click
-from typing import Optional
+from typing import Optional, Tuple
 from palm.plugins.dbt.dbt_palm_utils import shell_options, dbt_env_vars
 
 
@@ -32,9 +32,9 @@ def cli(
     persist: bool,
     full_refresh: bool,
     no_seed: bool,
-    models: Optional[tuple] = tuple(),
-    select: Optional[tuple] = tuple(),
-    macros: Optional[tuple] = tuple(),
+    models: Optional[Tuple] = tuple(),
+    select: Optional[Tuple] = tuple(),
+    macros: Optional[Tuple] = tuple(),
 ):
     """Runs the DBT repo."""
 
